@@ -10,18 +10,15 @@ C nor does it submit to any jurisdiction.
 C
 C     Parameters
 C
-      INTEGER JP32, JPLONO, J2NFFT, JPFFT, JPLOOK, JPMAX, JPMAXITER
+      INTEGER JP32, JPLONO, JPFFT, JPLOOK, JPMAX, JPMAXITER
       INTEGER JPMXTRY, JPTRNC, JPK, JPTRP1
       PARAMETER ( JP32 = 32 )
 C
-C     The following value for JPLONO (2560) will handle regular grids 
-C     from N1 to N720 derived from spectral truncations from T1 to
-C     T639.
-C
-Cjdc  PARAMETER ( JPLONO = 2560 , J2NFFT = 2 + JPLONO, JPFFT = 12000)
-c      PARAMETER ( JPLONO = 6000 , J2NFFT = 2 + JPLONO, JPFFT = 12000)
-      PARAMETER ( JPLONO = 8200 , J2NFFT = 2 + JPLONO, JPFFT = 12000)
+C     PARAMETER ( JPLONO = 2560 , JPFFT = 12000)  ! handles N1-N720, spectral truncations T1-T639
+C     PARAMETER ( JPLONO = 6000 , JPFFT = 12000)
+      PARAMETER ( JPLONO = 8200 , JPFFT = 12000)  ! [O|N]1280 require [5136|5120]+2 reals
       PARAMETER ( JPLOOK = 50)
+C     PARAMETER ( JPMAX = 2048 )
       PARAMETER ( JPMAX = 2560 )
       PARAMETER ( JPMAXITER = 10)
       PARAMETER ( JPMXTRY = 3 )
