@@ -1,11 +1,11 @@
 c
 C Copyright 1981-2012 ECMWF.
 C
-C This software is licensed under the terms of the Apache Licence 
+C This software is licensed under the terms of the Apache Licence
 C Version 2.0 which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 C
-C In applying this licence, ECMWF does not waive the privileges and immunities 
-C granted to it by virtue of its status as an intergovernmental organisation 
+C In applying this licence, ECMWF does not waive the privileges and immunities
+C granted to it by virtue of its status as an intergovernmental organisation
 C nor does it submit to any jurisdiction.
 C
 C**** "parim.h"
@@ -114,9 +114,13 @@ C                     (Real (360) / REAL (JPLONG) ).
 C
       INTEGER JPLONG, JPLAT, JPGTRUNC, JPSTRUNC
 C
+C     PARAMETER (JPLONG = 1440)
       PARAMETER (JPLONG = 4096)
-      PARAMETER (JPLAT  = 4000 )
+C     PARAMETER (JPLAT  = 2048)
+      PARAMETER (JPLAT  = 4000)
+C     PARAMETER (JPGTRUNC = 2048)
       PARAMETER (JPGTRUNC = 4000)
+C     PARAMETER (JPSTRUNC = 2047)
       PARAMETER (JPSTRUNC = 3999)
 C
       INTEGER JPLG01, JPLT01, JPPACK, JPML01
@@ -317,6 +321,7 @@ C
       INTEGER JPENSEMBLE, JPVERTICAL, JPBASE2
 C
       PARAMETER (JPENSEMBLE = 100)
+C     PARAMETER (JPVERTICAL = 100)
       PARAMETER (JPVERTICAL = 128)
       PARAMETER (JPBASE2 = 22)
 C
@@ -622,3 +627,9 @@ C     (see WAVEXX2, WV2DXX2, WV2DINT, WVQLIN2, WVQLINT, JPEXPAND)
 C
 CC    PARAMETER ( JPARRAYDIM_WAVE = 2880*1442)   !EMOS 000396
       PARAMETER ( JPARRAYDIM_WAVE = 3600*1802*2) !EMOS 4.0.0  <-- PRODGEN change
+C
+C --------------------------------------------------------------------
+C     Dimension for internal array for gaussian grid definitions
+      INTEGER JPMAXNG
+      PARAMETER ( JPMAXNG = 4000 )
+
