@@ -1,11 +1,11 @@
 /**
 * Copyright 1981-2012 ECMWF.
 *
-* This software is licensed under the terms of the Apache Licence 
+* This software is licensed under the terms of the Apache Licence
 * Version 2.0 which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 *
-* In applying this licence, ECMWF does not waive the privileges and immunities 
-* granted to it by virtue of its status as an intergovernmental organisation 
+* In applying this licence, ECMWF does not waive the privileges and immunities
+* granted to it by virtue of its status as an intergovernmental organisation
 * nor does it submit to any jurisdiction.
 */
 
@@ -28,7 +28,7 @@
 #endif
 
 #include "bufrgrib.h"
-#include "fortint.h"
+#include "common/fortint.h"
 #include "fileRead.h"
 #include "sizeRoutines.h"
 
@@ -63,13 +63,13 @@ static int grab(char * , char * , long ,long ,long * );
 static fortint waveLength(char * );
 
 #ifdef FOPEN64
-fortint readprod( char * prod_id, char * buffer, fortint * size, 
+fortint readprod( char * prod_id, char * buffer, fortint * size,
               fortint (*fileRead)(char *, fortint , void *),
               OFF_T (*fileSeek)(void *, OFF_T, fortint),
               OFF_T (*fileTell)(void *),
               void * stream)
 #else
-fortint readprod( char * prod_id, char * buffer, fortint * size, 
+fortint readprod( char * prod_id, char * buffer, fortint * size,
               fortint (*fileRead)(char *, fortint , void *),
               fortint (*fileSeek)(void *, fortint, fortint),
               fortint (*fileTell)(void *),
@@ -88,7 +88,7 @@ fortint readprod( char * prod_id, char * buffer, fortint * size,
 //             the product byte stream,
 //  stream = data describing the input stream (eg. FILE *).
 //
-//  Returns 
+//  Returns
 //    -1 if can't find product  (eg. end-of-file)
 //    -2 if internal processing error (malloc fail, file seek error)
 //    -3 if buffer too small for whole product.
@@ -163,7 +163,7 @@ fortint one = 1;
   if( prodlen == -4 ) return USER_BUFFER_TINY;
 
   if( prodlen < -4 ) {           /* special case for very large wave products */
-    fortint estimate; 
+    fortint estimate;
 
     estimate = -prodlen;
     prodlen = estimate - 128;
@@ -315,7 +315,7 @@ const char* big_prod_flag = NULL;
 /* See if the GRIB version is 0 ...
 */
   if ( THREE_BYTE_LONG(phold+4) == 24 ) {
-    length = 28;		     /* GRIB + section 1 */
+    length = 28;                   /* GRIB + section 1 */
 
 /* Check for presence of sections 2 and 3
 */
@@ -324,11 +324,11 @@ const char* big_prod_flag = NULL;
 
 /* Add up all lengths of sections
 */
-    return lentotal(hold, holdsize, leng, length, section2, section3, 
+    return lentotal(hold, holdsize, leng, length, section2, section3,
                     fileRead, stream);
   }
 
-  
+
 /* ... or version 2 ...
 */
 if ( hold[7] == 2 ){
@@ -340,13 +340,13 @@ if ( hold[7] == 2 ){
   if ( ( hold[21] != 0 ) || ( hold[22] != 0 ) ) {
 
 /* Nightmare fixup for very large GRIB products (eg 2D wave spectra).
-  
+
    If the most-significant of the 24 bits is set, this indicates a
    very large product; the size has to be rescaled by a factor of 120.
    This is a fixup to get round the GRIB code practice of representing
    a product length by 24 bits. It is only possible because the
    (default) rounding for GRIB products is 120 bytes.
-  
+
 */
     fortint fixlen;
 
@@ -357,15 +357,15 @@ if ( hold[7] == 2 ){
     {
       fortint largeLen;
       unsigned long code = 0;
-      
-	  big_prod_flag = getenv("ECMWF_CODED_BIG_PRODUCT");  
+
+      big_prod_flag = getenv("ECMWF_CODED_BIG_PRODUCT");
       if(big_prod_flag)
          if(strcmp(big_prod_flag,"OFF") == 0) return fixlen;
-      
+
       fixlen = (fixlen & 0x7fffff)*120;  /* first guess at length */
-     
+
       num = fixlen;
-    
+
       if( leng < num ) { /* -unsure - apparently test is given buffer is too small */
         num = fixlen - 128;
         numread = fileRead( hold + hsize, leng - hsize, stream);
@@ -377,28 +377,30 @@ if ( hold[7] == 2 ){
         return (-fixlen);
       }
       else {
-		  fortint fileReadResult =0;
+        fortint fileReadResult =0;
         if ( hsize < num) { /* buffer is big enough */
-	  /* go to the estimate minus 128 bytes to look after the 7777*/
+
+          /* go to the estimate minus 128 bytes to look after the 7777*/
           numread = fileRead( hold + hsize, num - hsize - 128, stream);
 
           if ( numread <= 0 ) {          /* eg. on END_OF_FILE */
             *holdsize -= numread;
             return *holdsize;
           }
-        	  /* search byte after byte for the 7777 in the stream and stop when found*/
-  		  do {
-		     if (num<numread) return MISPLACED_7777;
-		     fileReadResult = fileRead( hold + numread + hsize, 1, stream);
-		      
-		      if ( fileReadResult <= 0 ) {          /* eg. on END_OF_FILE ---should not happen*/
- 		           *holdsize += numread;
-			   *holdsize -= fileReadResult;
- 		           return *holdsize; /*returns the number of bytes actually read */
- 		      }     
- 		     numread += fileReadResult;
- 		     code = ( (code << 8) + hold[hsize + numread-1] ) & 0xFFFFFFFF;
-		    } while ( code != CODE_7777 );
+
+          /* search byte after byte for the 7777 in the stream and stop when found*/
+          do {
+            if (num<numread) return MISPLACED_7777;
+            fileReadResult = fileRead( hold + numread + hsize, 1, stream);
+
+            if ( fileReadResult <= 0 ) {          /* eg. on END_OF_FILE ---should not happen*/
+                 *holdsize += numread;
+                 *holdsize -= fileReadResult;
+                 return *holdsize; /*returns the number of bytes actually read */
+            }
+            numread += fileReadResult;
+            code = ( (code << 8) + hold[hsize + numread-1] ) & 0xFFFFFFFF;
+          } while ( code != CODE_7777 );
           hsize = numread;
         }
         *holdsize = hsize;
@@ -412,7 +414,7 @@ if ( hold[7] == 2 ){
 
   }
 
-  length = 24;		     /* GRIB + section 1 */
+  length = 24;                     /* GRIB + section 1 */
 
 /* Check for presence of sections 2 and 3
 */
@@ -421,7 +423,7 @@ if ( hold[7] == 2 ){
 
 /* Add up all lengths of sections
 */
-  return lentotal(hold, holdsize, leng, length, section2, section3, 
+  return lentotal(hold, holdsize, leng, length, section2, section3,
                     fileRead, stream);
 
 }
@@ -464,7 +466,7 @@ fortint next, next_sec = 4;
       return *holdsize;
     }
     hsize = length;
-  } 
+  }
   *holdsize = hsize;
 
 /* Get the size of remaining sections
@@ -478,7 +480,7 @@ fortint next, next_sec = 4;
         return *holdsize;
       }
       hsize = length + 4;
-    } 
+    }
     *holdsize = hsize;
     length += THREE_BYTE_LONG(phold+length);
   }
@@ -532,7 +534,7 @@ fortint next, next_sec = 3;
    adding up the lengths
 */
 
-/* Add on the length of section 1 and ensure enough of product is in 
+/* Add on the length of section 1 and ensure enough of product is in
    memory to continue
 */
   length = SECT_0_LEN + THREE_BYTE_LONG(phold+4);
@@ -545,7 +547,7 @@ fortint next, next_sec = 3;
     }
     hsize = length + 4;
     *holdsize = hsize;
-  } 
+  }
 
 /* Check for presence of section 2
 */
@@ -564,7 +566,7 @@ fortint next, next_sec = 3;
       }
       hsize = length + 4;
       *holdsize = hsize;
-    } 
+    }
   }
 
 /* Add on the size of section 5
@@ -610,7 +612,7 @@ fortint num, length;
 /* Have to step through individual sections adding up the lengths
 */
 
-/* Add on the length of section 1 and ensure enough of product is in 
+/* Add on the length of section 1 and ensure enough of product is in
    memory to continue
 */
   length = SECT_0_LEN + THREE_BYTE_LONG(phold+4);
@@ -623,7 +625,7 @@ fortint num, length;
     }
     hsize = length + 4;
     *holdsize = hsize;
-  } 
+  }
 
 /* Get the size of remaining section
 */
@@ -637,7 +639,7 @@ fortint num, length;
   return length;
 }
 
-static fortint prodsize(fortint code, char * hold, fortint leng, fortint * holdsize, 
+static fortint prodsize(fortint code, char * hold, fortint leng, fortint * holdsize,
                      fortint (*fileRead)(), void * stream)
 /*
 //  Returns size of BUFR, GRIB, BUDG, TIDE, DIAG product in bytes.
@@ -652,7 +654,7 @@ static fortint prodsize(fortint code, char * hold, fortint leng, fortint * holds
 long lcode = code;
 
   *holdsize = 4;
-  switch( lcode ) 
+  switch( lcode )
   {
      case BUFR: memcpy(hold,"BUFR",4);
                 return bufrsize( hold, leng, holdsize, fileRead, stream);
@@ -775,9 +777,9 @@ long s0;
     if( grab(buffer, size, 3, 1, &bytes_read) != 0) return (-1);
     section4 = THREE_BYTE_LONG(size);
     /*  If it happens that the section 2 is not the difference of bytes
-        between the real message length and the coded message length, that mean that 
-        the 120 trick is not used, if so return the real length   */ 
-     if(section4 > 120 ) 
+        between the real message length and the coded message length, that mean that
+        the 120 trick is not used, if so return the real length   */
+     if(section4 > 120 )
        return rtotal;
     section4 = total + 3 - bytes_read - section4;
 
